==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+245"/>
      <source>Mesh</source>
      <translation>Сітка</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation type="unfinished">Curve on mesh...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation type="unfinished">Curve on mesh</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-191"/>
      <source>Mesh</source>
      <translation>Сітка(Меш)</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>Створення сітки з форми ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>Теселяція форми</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+106"/>
      <source>Mesh</source>
      <translation>Сітка(Меш)</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation type="unfinished">Create section from mesh and plane</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>Секція</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Mesh</source>
      <translation>Сітка(Меш)</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>Обрізати сітки площиною</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>Обрізати сітку площиною</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>Створити</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation type="unfinished">Close wire</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>Очистити</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>Скасувати</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation type="unfinished">Wrong mesh picked</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>Жодної точки не вибрано</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation type="unfinished">Curve on mesh</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>Каркас</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation type="unfinished">Snap tolerance to vertexes</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation> пікс.</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation type="unfinished">Split threshold</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation type="unfinished">Spline Approximation</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation type="unfinished">Tolerance to mesh</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation type="unfinished">Continuity</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation type="unfinished">Maximum curve degree</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation>Початок</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>Теселяція</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>Форми</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation>Параметри сітки</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>Стандартно</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation>Мефісто</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation type="unfinished">Define segments by face colors</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation type="unfinished">Apply face colors to mesh</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation type="unfinished">Angular deviation:</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation type="unfinished">Relative surface deviation</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>Максимальна довжина ребра:</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation>Чистота:</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>Дуже грубо</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation>Шорсткий</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation>Помірний</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation>Добре</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>Дуже добре</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>Визначено користувачем</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation>Сортування за розміром сітки:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>Елементи на ребро:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation>Елементів на радіус кривизни:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>Оптимізувати поверхню</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>Елементи другого порядку</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation>Домінуючий чотирикутник</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation>Параметри</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>Поверхня відхилення:</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation>Макс. довжина ребра:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+225"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Спочатку оберіть форму для злиття.</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>Документ '%1' не знайдено.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Select plane</source>
      <translation>Оберіть площину</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation type="unfinished">Please select a plane at which you section the mesh.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Select plane</source>
      <translation>Оберіть площину</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Оберіть площину за допомогою якої ви будете обрізати сітку.</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>Частина Сітки</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+290"/>
      <source>Mesh</source>
      <translation>Сітка</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation type="unfinished">Curve on mesh...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation type="unfinished">Curve on mesh</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-235"/>
      <source>Mesh</source>
      <translation>Сітка(Меш)</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>Створення сітки з форми ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>Теселяція форми</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+150"/>
      <source>Mesh</source>
      <translation>Сітка(Меш)</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation>Створити секцію з полігональної сітки і площини</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>Секція</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Mesh</source>
      <translation>Сітка(Меш)</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>Обрізати сітки площиною</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>Обрізати сітку площиною</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>Створити</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation type="unfinished">Close wire</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>Очистити</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>Скасувати</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation type="unfinished">Wrong mesh picked</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>Жодної точки не вибрано</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation type="unfinished">Curve on mesh</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>Каркас</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation type="unfinished">Snap tolerance to vertexes</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation> пікс.</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation type="unfinished">Split threshold</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation type="unfinished">Spline Approximation</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation type="unfinished">Tolerance to mesh</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation>Неперервність</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation type="unfinished">Maximum curve degree</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation>Початок</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>Теселяція</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>Форми</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation>Параметри сітки</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>Стандартно</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation>Мефісто</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation type="unfinished">Define segments by face colors</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation type="unfinished">Apply face colors to mesh</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation>Кутове відхилення:</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation>Відносне відхилення поверхні</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>Максимальна довжина ребра:</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation>Чистота:</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>Дуже грубо</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation>Шорсткий</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation>Помірний</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation>Добре</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>Дуже добре</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>Визначено користувачем</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation>Сортування за розміром сітки:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>Елементи на ребро:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation>Елементів на радіус кривизни:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>Оптимізувати поверхню</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>Елементи другого порядку</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation>Домінуючий чотирикутник</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation>Параметри</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>Поверхня відхилення:</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation>Макс. довжина ребра:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+226"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Спочатку оберіть форму для злиття.</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>Документ '%1' не знайдено.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+137"/>
      <source>Select plane</source>
      <translation>Оберіть площину</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation type="unfinished">Please select a plane at which you section the mesh.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Select plane</source>
      <translation>Оберіть площину</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Оберіть площину за допомогою якої ви будете обрізати сітку.</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Trim by plane</source>
      <translation type="unfinished">Trim by plane</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Select the side you want to keep.</source>
      <translation type="unfinished">Select the side you want to keep.</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Inner</source>
      <translation>Внутрішній</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Outer</source>
      <translation>Зовнішній</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Split</source>
      <translation>Розділити</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>Частина Сітки</translation>
    </message>
  </context>
</TS>
